#
# spec file for package budgie-desktop
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2016 Ikey Doherty <ikey@solus-project.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           budgie-desktop
Version:        10.4
Release:        lp150.1.10
Summary:        GTK3 Desktop Environment
License:        GPL-2.0+ AND LGPL-2.1
Group:          System/GUI/Other
Url:            https://solus-project.com/budgie/
Source:         https://github.com/budgie-desktop/budgie-desktop/releases/download/v%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM: temp patch for sandbox changes in Meson 0.43.0.
# Proper fix is in upstream master (gh#budgie-desktop/budgie-desktop#1194).
Patch0:         fix-meson-build.patch
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  meson >= 0.41.2
BuildRequires:  pkg-config
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gnome-bluetooth-1.0)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libgnome-menu-3.0)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libwnck-3.0)
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(libmutter-1)
%else
BuildRequires:  pkgconfig(libmutter)
%endif
BuildRequires:  sassc
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(uuid)

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       gnome-session
Requires:       gnome-settings-daemon

#Recommends:     gnome-screensaver
Recommends:     NetworkManager-applet
Recommends:     gnome-backgrounds
Recommends:     gnome-control-center

%description
Budgie Desktop is the flagship desktop for the Solus Operating System.

%package -n typelib_1_0-Budgie-0_1
Summary:        Introspection bindings for the Budgie Desktop
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n typelib_1_0-Budgie-0_1
This package provides GObject Introspection files required for
developing Budgie Applets using interpreted languages, such as Python
GObject Introspection bindings.

%package devel
Summary:        Development files for the Budgie Desktop
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}-%{release}
Requires:       typelib_1_0-Budgie-0_1 = %{version}-%{release}

%description devel
This package provides development files required for software to be
able to use and link against the Budgie APIs, to create their own
applets for the Budgie Panel.

%package docs
Summary:        Documentation files for the Budgie Desktop
Group:          Documentation/HTML

%description docs
This package provides API Documentation for the Budgie Plugin API, in the
GTK-Doc HTML format.

%package -n libraven0
Summary:        Shared library for Raven
Group:          System/Libraries

%description -n libraven0
Budgie Desktop Notification Center.

%package -n libbudgietheme0
Summary:        Shared library for Budgie theming
Group:          System/Libraries

%description -n libbudgietheme0
Budgie theming engine shared library package.

%package -n libbudgie-plugin0
Summary:        Shared library for Budgie plugins
Group:          System/Libraries

%description -n libbudgie-plugin0
Shared library for budgie plugins to link against.

%prep
%setup -q
%patch0 -p1
cp -r src/gvc subprojects

%build
%meson
%meson_build

%install
export LANG=en_US.UTF-8
%meson_install

# GNOME Screensaver missing in openSUSE
rm %{buildroot}/%{_sysconfdir}/xdg/autostart/budgie-desktop-screensaver.desktop

%find_lang %{name}

%post
%glib2_gsettings_schema_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_post
%icon_theme_cache_postun

%post   -n libraven0 -p /sbin/ldconfig
%postun -n libraven0 -p /sbin/ldconfig

%post   -n libbudgietheme0 -p /sbin/ldconfig
%postun -n libbudgietheme0 -p /sbin/ldconfig

%post   -n libbudgie-plugin0 -p /sbin/ldconfig
%postun -n libbudgie-plugin0 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root)
%doc LICENSE LICENSE.LGPL2.1
%dir %{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_bindir}/budgie-*
%{_datadir}/applications/budgie-*.desktop
%{_datadir}/glib-2.0/schemas/com.solus-project.*.gschema.xml
%{_datadir}/gnome-session/sessions/budgie-desktop.session
%{_datadir}/icons/hicolor/scalable/*/*.svg
%{_datadir}/xsessions/budgie-desktop.desktop
%{_libdir}/budgie-desktop/
%{_sysconfdir}/xdg/autostart/budgie-desktop-nm-applet.desktop

%files -n libraven0
%defattr(-,root,root)
%{_libdir}/libraven.so.*

%files -n libbudgietheme0
%defattr(-,root,root)
%{_libdir}/libbudgietheme.so.*

%files -n libbudgie-plugin0
%defattr(-,root,root)
%{_libdir}/libbudgie-plugin.so.*

%files devel
%dir %{_includedir}/budgie-desktop
%{_includedir}/budgie-desktop/*.h
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/Budgie-1.0.gir
%{_datadir}/vala/vapi/budgie-1.0.*

%files -n typelib_1_0-Budgie-0_1
%{_libdir}/girepository-1.0/Budgie-1.0.typelib

%files docs
%{_datadir}/gtk-doc/html/budgie-desktop/

%changelog
* Thu Nov 30 2017 qantas94heavy@gmail.com
- Add fix-meson-build.patch: fixes gvc subproject sandbox issue
  with Meson 0.43.0
* Mon Sep 18 2017 mailaender@opensuse.org
- Update pkgconfig libmutter-0 to libmutter-1
* Sun Aug 20 2017 mailaender@opensuse.org
- Drop sed fix bdugie-desktop typo (resolved upstream)
* Tue Aug 15 2017 mailaender@opensuse.org
- Update to version 10.4 "Irish Summer"
- Drop upstream gtk-3.22.14+raven-crash-fix.patch
- Drop upstream meson-0.41.patch
- Drop upstream 0001-wm-Default-to-an-empty-rpath.patch
* Mon Jul 24 2017 matcherapy@gmail.com
- fix empty rpath 0001-wm-Default-to-an-empty-rpath.patch
* Sat Jul 22 2017 mailaender@opensuse.org
- Fix build with meson 0.41 using meson-0.41.patch
* Tue Jun 13 2017 jengelh@inai.de
- Redo descriptions.
* Sun Jun  4 2017 mailaender@opensuse.org
- Add gtk-3.22.14+raven-crash-fix.patch to fix #918
* Fri Apr 21 2017 dev+novell@devmotion.de
- Update to v10.3.1
- See https://github.com/budgie-desktop/budgie-desktop/releases/tag/v10.3.1
* Fri Jan 27 2017 mailaender@opensuse.org
- Add https://en.opensuse.org/SourceUrls
- Fix standard-dir-owned-by-package rpmlint warnings
- Implement shared library policy
* Fri Dec 16 2016 ikey.doherty@gmail.com
- Update to v10.2.9 - a maintenance release
- See: https://github.com/budgie-desktop/budgie-desktop/releases/tag/v10.2.9
* Wed Nov  9 2016 sfalken@opensuse.org
- Fixed /usr/bin ownership conflict for F24
* Sat Nov  5 2016 sfalken@opensuse.org
- Added docbook2X buildrequire for Fedora, builds for F24 now
* Sat Nov  5 2016 sfalken@opensuse.org
- Added conditional BuildDeps for Fedora
* Sat Nov  5 2016 sfalken@opensuse.org
- Did some spec cleanup, for maintainability and clarity
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Yet another Fedora change. Strongly considering dropping support for them.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Explicitly require gtk-doc for Fedora.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Fix even more build failures with ancient Vala. Circa 1940.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Reflow patch series specifically to this OBS repo
- Fix build failures on Fedora 22, 23, and openSUSE Leap 42.1 by
  allowing old ibus versions and removing use of Source.REMOVE which
  is unavailable in their vala versions.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Update to Budgie Desktop 10.2.8
- Sync some essential patches for an enhanced experience
* Thu Jul 28 2016 ikey.doherty@gmail.com
- Remove the screensaver component for now
* Mon Jul 11 2016 ikey.doherty@gmail.com
- Update to v10.2.6
  - https://github.com/solus-project/budgie-desktop/releases/tag/v10.2.6
* Sun Mar 27 2016 ikey.doherty@gmail.com
- Fix version number in documentation - we didn't update it in this
  point release
* Sun Mar 27 2016 ikey.doherty@gmail.com
- Update to v10.2.5, and exclude .la files
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Account for html files too
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Fix noobish packaging issues
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Add -docs subpackage
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Update to 10.2.4
* Sun Jan  3 2016 ikey.doherty@gmail.com
- Fix many linking/portability issues on other distributions
- Fix nm-applet-likes-small-holes bug (size of x11 tray icons)
- Respect and follow screen resolution changes
- Fix background corruption on resume with NVIDIA gpus
- Fix use of colours for backgrounds
- Replace polkit-gnome dependency with our own new budgie-polkit
- Refactor much of the codebase into smallerl ibraries
- Updated translations
- Fix bug #166 (firefox becomes homeless)
- Fix uhm-is-that-youtube-i-see-through-gedit-thar transparency issue
- Consumed several pizzas
* Wed Dec 30 2015 ikey.doherty@gmail.com
- Use find_lang due to borked directory ownership
* Wed Dec 30 2015 ikey.doherty@gmail.com
- Drop requirements down to GNOME 3.16 stack for openSUSE Leap 42 users
- Introduce many translations
- Fix derpiness of panel when using Raven (moving screen edge)
- Partially fix mumble notifications (more to happen here yet)
- Use unique desktop name (XDG_CURRENT_DESKTOP=Budgie:GNOME)
- Ship our own nm-applet .desktop launcher until we have our own network settings
- Go back to "view-grid-symbolic" icon
* Mon Dec 28 2015 ikey.doherty@gmail.com
- Drop gnome-control-center dependency, causing issues on Fedora
- Apply some patches to enable building on 3.16 GNOME stack (from git)
* Mon Dec 28 2015 ikey.doherty@gmail.com
- Initial packaging for openSUSE:Factory and Fedora 23
